==> nucliadb_sdk-2.11.0.post277-py3-none-any.whl: nucliadb_sdk/__init__.py <==
# Copyright (C) 2021 Bosutech XXI S.L.
#
# nucliadb is offered under the AGPL v3.0 and as commercial software.
# For commercial licensing, contact us at info@nuclia.com.
#
# AGPL:
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

# Old SDK APIs that should eventually be removed
from nucliadb_sdk.entities import Entity
from nucliadb_sdk.file import File
from nucliadb_sdk.knowledgebox import KnowledgeBox
from nucliadb_sdk.labels import DEFAULT_LABELSET, Label, LabelSet, LabelType
from nucliadb_sdk.utils import (
    create_knowledge_box,
    delete_kb,
    get_kb,
    get_or_create,
    list_kbs,
)
from nucliadb_sdk.v2 import NucliaSDK, Region, exceptions
from nucliadb_sdk.vectors import Vector

__all__ = (
    "NucliaSDK",
    "Region",
    "exceptions",
    # OLD support APIs
    # Plan on removing these in the future
    "File",
    "KnowledgeBox",
    "Entity",
    "LabelType",
    "Label",
    "LabelSet",
    "DEFAULT_LABELSET",
    "Vector",
    "get_kb",
    "get_or_create",
    "create_knowledge_box",
    "delete_kb",
    "list_kbs",
)

==> nucliadb_sdk-2.13.0.post307-py3-none-any.whl: nucliadb_sdk/__init__.py <==
# Copyright (C) 2021 Bosutech XXI S.L.
#
# nucliadb is offered under the AGPL v3.0 and as commercial software.
# For commercial licensing, contact us at info@nuclia.com.
#
# AGPL:
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as
# published by the Free Software Foundation, either version 3 of the
# License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.

# Old SDK APIs that should eventually be removed
from nucliadb_sdk.entities import Entity
from nucliadb_sdk.file import File
from nucliadb_sdk.knowledgebox import KnowledgeBox
from nucliadb_sdk.labels import DEFAULT_LABELSET, Label, LabelSet, LabelType
from nucliadb_sdk.utils import (
    create_knowledge_box,
    delete_kb,
    get_kb,
    get_or_create,
    list_kbs,
)
from nucliadb_sdk.v2 import NucliaSDK, NucliaSDKAsync, Region, exceptions
from nucliadb_sdk.vectors import Vector

__all__ = (
    "NucliaSDK",
    "NucliaSDKAsync",
    "Region",
    "exceptions",
    # OLD support APIs
    # Plan on removing these in the future
    "File",
    "KnowledgeBox",
    "Entity",
    "LabelType",
    "Label",
    "LabelSet",
    "DEFAULT_LABELSET",
    "Vector",
    "get_kb",
    "get_or_create",
    "create_knowledge_box",
    "delete_kb",
    "list_kbs",
)
